@@ -557,7 +557,7 @@ static void do_activate(gpointer object, gpointer user_data)
 		num_day = (num_day%30);
 		num_week = num_day/7;
 		num_day = (num_day%7);
-		
+
 		if (num_year > 0)
 			yfmt = g_strdup_printf(ngettext("%d year", "%d years", num_year), num_year);
 		if (num_mon > 0)
@@ -566,11 +566,11 @@ static void do_activate(gpointer object, gpointer user_data)
 			wfmt = g_strdup_printf(ngettext("%d week", "%d weeks", num_week), num_week);
 
 		fmt = g_strdup_printf("%s%s%s%s%s",
-			yfmt?yfmt:"",
-			yfmt&&(mfmt||wfmt)?", ":"",
-			mfmt?mfmt:"",
-			(yfmt||mfmt)&&wfmt?", ":"",
-			wfmt?wfmt:""
+			yfmt ? yfmt:"",
+			yfmt && mfmt ? ", ":"",
+			mfmt ? mfmt:"",
+			(yfmt||mfmt) && wfmt ? ", ":"",
+			wfmt ? wfmt:""
 			);
 			
 		label = gtk_label_new(fmt);
